@@ -1,22 +1,35 @@
+#[deny(unused_imports)]
 #[cfg(test)]
 pub mod test {
-    use crate::{get_all, get_by_id, get_id_by_name, random};
-
+    use crate::{get_all, get_by_id, get_id_by_name};
     #[test]
     fn test_get_all() {
         let list = get_all(None);
-        assert_eq!(list.len(), 151);
-        println!("{:?}", list);
+        assert_eq!(list.len(), 251);
     }
     #[test]
     fn test_non_english_get_all_pokemon_get_bulbasaur() {
         let bulbasaur_jp = get_by_id(1, Some("jp"));
         assert_eq!(bulbasaur_jp, "フシギダネ");
     }
-
+    #[test]
+    fn chikorita_test_default_locale() {
+        let chikorita = get_by_id(152, None);
+        assert_eq!(chikorita, "Chikorita");
+    }
+    #[test]
+    fn test_crossing_locale_and_given_pokemon_look_for_alternate_vector_for_finding_the_pokemon() {
+        let id = get_id_by_name("フシギダネ", Some("en"));
+        assert_eq!(id, 1);
+    }
+    #[test]
+    fn test_crossing_locale_and_given_pokemon_en_in_russian_locale() {
+        let id = get_id_by_name("Blastoise", Some("ru"));
+        assert_eq!(id, 9);
+    }
     #[cfg(test)]
     mod panic_tests {
-        use super::*;
+        use crate::{get_all, get_by_id, get_id_by_name, random};
 
         #[test]
         #[should_panic]
